<template>
  <el-bus-crud v-bind="tableConfig" />
</template>

<script>
import { getSortConfig } from '@/utils/form-item-config'
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/flower/zone/page',
        columns: [
          { label: '专区标题', prop: 'name' },
          {
            label: '专区图片',
            formatter: (row) => (
              <el-bus-image
                src={row.bgUrl}
                lazy={true}
                style="height:44px"
              ></el-bus-image>
            ),
          },
          { label: '排序', prop: 'seq' },
          { label: '状态', prop: 'statusStr' },
        ],
        searchForm: [
          {
            type: 'row',
            items: [{ label: '专区标题', id: 'name', type: 'input' }],
          },
        ],
        form: [
          {
            label: '专区标题：',
            id: 'name',
            type: 'input',
            rules: {
              required: true,
              message: '请输入专区标题',
              trigger: 'blur',
            },
          },
          {
            label: '专区图片：',
            id: 'bgUrl',
            type: 'bus-upload',
            el: {
              listType: 'picture-card',
              limit: 1,
              limitSize: 2,
              tipText: '大小不超过2M',
              valueType: 'string',
            },
            rules: {
              required: true,
              message: '请上传专区图片',
            },
            forceDisabled: true,
          },
          {
            ...getSortConfig('seq'),
          },
        ],
        extraButtons: [
          {
            text: (row) => (row.status === 'unpublished' ? '发布' : '下架'),
            atClick: async (row) => {
              const action = row.status === 'unpublished' ? '发布' : '下架'
              try {
                await this.$elBusUtil.confirm(`确定要${action}吗？`)
                const { code } = await this.$elBusHttp.request(
                  'flower/api/flower/zone/page/changeStatus',
                  { params: { id: row.id } }
                )
                if (code === 0) {
                  this.$message.success(`${action}成功`)
                }
              } catch (e) {
                return false
              }
            },
          },
          {
            text: '查看商品',
            atClick: (row) => {
              const url = this.$router.resolve(
                `${this.$route.path}/${row.id}`
              ).href
              window.open(url, '_blank')
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '专区列表',
    }
  },
}
</script>
